# --------------------------------------------------------------
# Applied Statistics / Statistical methods for the Biosciences
# Day 3: Regression analysis
# Beetle example
# Bo Markussen
# December 2, 2021
# --------------------------------------------------------------

# Install gof-package from GitHub
# > install.packages("devtools")
# > devtools::install_github("kkholst/gof")

# Load libraries we will be using
library(dobson)
library(gof)
library(LabApplStat)

# Library to make fancy annotations
library(latex2exp)

# Use beetle data from dobson package
data(beetle)

# Make simply plot
ggplot(beetle,aes(x=x,y=y/n)) + geom_point() + geom_smooth(method="lm") +
  xlab(TeX('$\\log_{10}$(CS_2 mg/l)')) + ylab("Proportion of dead beetles") +
  theme_light()
ggsave("../slides/figur/beetle.png",width=3,height=3)

# Make plot of design in relation to Lack-of-Fit test.
plot(DD(~x+factor(x),data=beetle))
ggsave("../slides/figur/beetle_DD.png",width=3,height=3)

# Make probit regression
m1 <- glm(cbind(y,n-y)~x,data=beetle,family=binomial(link="probit"))

# Make probit plot
ggplot(beetle,aes(x=x,y=qnorm(y/n))) + geom_point() + geom_smooth(method="lm") +
  xlab(TeX('$\\log_{10}$(CS_2 mg/l)')) + ylab("qnorm(proportion of dead beetles)") +
  theme_light()
ggsave("../slides/figur/beetle_qnorm.png",width=3,height=3)


# Make residual plot
qplot(x=beetle$x,y=qnorm(beetle$y/beetle$n)-predict(m1)) + geom_point() + geom_hline(yintercept=0,lty=2) +
  xlab(TeX('$\\log_{10}$(CS_2 mg/l)')) + ylab("residuals") +
  theme_light()
ggsave("../slides/figur/beetle_residuals.png",width=3,height=3)

# Make cumulative residuals
pdf(file="../slides/figur/beetle_cumres.pdf",width=10,height=5)
par(mfrow=c(1,2))
plot(cumres(m1))
dev.off()

# Make a model where dosis is used as a categorical factor
m0 <- glm(cbind(y,n-y)~factor(x),data=beetle,family=binomial(link="probit"))

# Lack-of-Fit test: Test m1 as a hypothesis in m0
anova(m1,m0,test="Chisq")

# Hypothesis test
drop1(m1,test="Chisq")

# Parameter estimates and confidence intervals
cbind(estimate=coef(m1),confint(m1))

# Scale parameter in the tolerance distribution
1/cbind(estimate=coef(m1),confint(m1))[2,c(1,3,2)]

# Mean parameter in the tolerance distribution
# This may also be used for other quantiles than 50pct
emmeans_ED(m1,p=0.5,tran="log10")

# Alternatively via the car-package
car::deltaMethod(m1,"-alpha/beta",parameterNames=c("alpha","beta"))


# ----------------------------------------------------------------
# Plot of predicted probabilities (with 95pct confidence limits)
# ----------------------------------------------------------------

# make prediction with approximate 95pct confidence limits
new_x <- seq(1.6,1.9,0.005)
bHat  <- predict(m1,newdata=data.frame(x=new_x),se.fit=TRUE)
pHat  <- pnorm(bHat$fit)
lowerCI <- pnorm(bHat$fit-1.96*bHat$se.fit)
upperCI <- pnorm(bHat$fit+1.96*bHat$se.fit)

colors <- c("data"="black","model"="blue","95% confidence interval"="lightblue")
ggplot() + 
  geom_ribbon(aes(x=new_x,ymin=lowerCI,ymax=upperCI,fill="95% confidence interval"),col="lightblue") +
  geom_line(aes(x=new_x,y=pHat,col="model")) + 
  geom_point(aes(x=x,y=y/n,col="data"),data=beetle) + 
  labs(y="Probability for death",
       x=TeX('$\\log_{10}(CS_2$ mg/l)'),
       col="",
       fill="") +
  scale_color_manual(values=colors[1:2],limits=names(colors[1:2])) +
  scale_fill_manual(values=colors[3]) +
  theme_light()
ggsave("../slides/figur/beetle_data_modelfit.png",width=14,height=8,unit="cm")
